function plotBistable(lparam)

% generate figures for bistable circuits

close all;

global data       % normalized fluorescence data
global S          % separatrix data

% parameters for simulation

param=exp(lparam);

KM1=param(1); kpc1=param(2); KMF1=param(3); kpFc1=param(4); KMh1=param(5); khc1=param(6); kDA1=param(7); kAI1=param(8); kDAI1=param(9);
KM2=param(10); kpc2=param(11); KMF2=param(12); kpFc2=param(13); KMh2=param(14); khc2=param(15); kDA2=param(16); kAI2=param(17); kDAI2=param(18);
Rv=param(19); Rhv=param(20); Dv=param(21); 

% enzyme concentrations

R=30*10^(-9); Rh=4.4*10^(-9);

dt=60; 

% Figures for the phaseplane experiments

C_exp=[0.5 1 1; 1 0.5 1; 0.5 1 1; 1 0.5 1; 1 0.5 1; 1 0.5 1; 0.5 1 1; 0.5 1 1; 0.5 1 1; 1 0.5 1; 0.45 0.2 0.45; 0.2 0.45 0.45];
C_sim=[0.5 1 1; 1 0.5 1; 0.5 1 1; 1 0.5 1; 1 0.5 1; 1 0.5 1; 0.5 1 1; 0.5 1 1; 0.5 1 1; 1 0.5 1; 1 0.5 1; 0.5 1 1]*0.9;

for n=1:12

Txpoints=data{n,1}';
Tampoints=data{n,2}';
A1tot=data{n,3};
A2tot=data{n,4};
I1tot=data{n,5};
I2tot=data{n,6};

L=length(Txpoints);

% x0=[D21=Tx A1 I1 D21A1 A1I1 D12=Tam A2 I2 D12A2 A2I2];

D21tot=75*10^(-9); D12tot=100*10^(-9);
x0=[D21tot A1tot I1tot 0 0 D12tot A2tot I2tot 0 0]'; 

% equilibrate for 30min without enzymes'

tspan=[0:dt:1800];
options=odeset('AbsTol',1e-10); % Set tolerances
[t,ypre]=ode23s('bistabledefine',tspan,x0, options,  KM1, kpc1, KMF1, kpFc1, KMh1, khc1, 10^5, 10^5, 10^5, KM2, kpc2, KMF2, kpFc2, KMh2, khc2, 10^5, 10^5, 10^5, 0, 0);

% simulation run

tspan=[0:dt:dt*(L-1)];
[t,y]=ode23s('bistabledefine',tspan,ypre(31,:), options,  KM1, kpc1, KMF1, kpFc1, KMh1, khc1, kDA1, kAI1, kDAI1, KM2, kpc2, KMF2, kpFc2, KMh2, khc2, kDA2, kAI2, kDAI2, R, Rh);

Txsimpoints=y(:,4)/D21tot;
Tamsimpoints=y(:,9)/D12tot;

figure(1)          % Figure S8A in paper
     plot(tspan/3600,Txpoints*75,'r',tspan/3600,Tampoints*100,'g','Linewidth',2);hold on
     drawnow
     
figure(2)          % Figure S8B in paper
     plot(tspan/3600,Txsimpoints*75,'r',tspan/3600,Tamsimpoints*100,'g','Linewidth',2); hold on  
     drawnow

figure(3)          % Figure 5C in paper
     plot(Tampoints*100,Txpoints*75,'d-','Color',C_exp(n,:),'Linewidth',2); hold on  
     drawnow

figure(4)          % Figure 5D in paper
     plot(Tamsimpoints*100,Txsimpoints*75,'d-','Color',C_sim(n,:),'Linewidth',2); hold on
     drawnow
end

figure(1)
     axis([0 11 -10 110])
     xlabel('Time (hr)','Fontsize',20); ylabel('[Sw ON] (nM)','Fontsize',20);
     legend('Sw_{21}', 'Sw_{12}'); legend boxoff; set(gca,'Fontsize',20);
%    print -depsc2 PhaseplaneTime.eps;

figure(2)
     axis([0 11 -10 110])
     xlabel('Time (hr)','Fontsize',20); ylabel('[Sw ON] (nM)','Fontsize',20);
     legend('Sw_{21}', 'Sw_{12}'); legend boxoff; set(gca,'Fontsize',20);
     saveas(gcf,'PhaseplaneTime_model','fig');
%    print -depsc2 PhaseplaneTime_model.eps;

figure(3)
     axis([-10 110 -7 82])
     xlabel('[Sw_{12} ON] (nM)','Fontsize',20); ylabel('[Sw_{21} ON] (nM)','Fontsize',20);
     set(gca,'YTick',[0 15 30 45 60 75]);
     set(gca,'Fontsize',20);
%    print -depsc2 Phaseplane.eps;

figure(4)
     axis([-10 110 -7 82])
     plot(smooth(S(:,1),8)*100,smooth(S(:,2),8)*75,'b-','Linewidth',3)
     xlabel('[Sw_{12} ON] (nM)','Fontsize',20); ylabel('[Sw_{21} ON] (nM)','Fontsize',20);
     set(gca,'YTick',[0 15 30 45 60 75]);
     set(gca,'Fontsize',20);
%    print -depsc2 Phaseplane_model.eps;

%  Figures for the bifurcation diagram experiments

pos=[16 17 18 19 20 11 12 13 14 15 6 7 8 9 10 1 2 3 4];
stable=['B ';'B ';'M2';'M2';'M2';'B ';'B ';'B ';'B ';'M2';'M1';'B ';'B ';'B ';'B ';'M1';'B ';'B ';'B '];
stc=[3 3 4 4 4 3 3 3 3 4 5 3 3 3 3 5 3 3 3];
C=[0.7 0 0; 0 0 1; 1 0 1; 0 1 1; 0 0.8 0];

for i=1:19,
	for j=1:2,
		n=10+2*i+j;
        Txpoints=data{n,1}';
        Tampoints=data{n,2}';
        A1tot=data{n,3};
        A2tot=data{n,4};
        I1tot=data{n,5};
        I2tot=data{n,6};

        L=length(Txpoints);
        Lt=420;

% x0=[D21=Tx A1 I1 D21A1 A1I1 D12=Tam A2 I2 D12A2 A2I2];

D21tot=75*10^(-9)*Dv; D12tot=100*10^(-9);
x0=[D21tot A1tot I1tot 0 0 D12tot A2tot I2tot 0 0]'; 

% equilibrate for 30 min without enzymes'

tspan=[0:dt:1800];
options=odeset('AbsTol',1e-10); % Set tolerances
[t,ypre]=ode23s('bistabledefine',tspan,x0, options,  KM1, kpc1, KMF1, kpFc1, KMh1, khc1, 10^5, 10^5, 10^5, KM2, kpc2, KMF2, kpFc2, KMh2, khc2, 10^5, 10^5, 10^5, 0, 0);

% simulation run

tspan=[0:dt:dt*(Lt-1)];
[t,y]=ode23s('bistabledefine',tspan,ypre(31,:), options,  KM1, kpc1, KMF1, kpFc1, KMh1, khc1, kDA1, kAI1, kDAI1, KM2, kpc2, KMF2, kpFc2, KMh2, khc2, kDA2, kAI2, kDAI2, R, Rh);

Txsimpoints=y(:,4)/D21tot;
Tamsimpoints=y(:,9)/D12tot;

%figure(8)         % Time-courses of bifurcation diagram experiments
%     plot([0:dt:dt*(L-1)],Txpoints,'b.',[0:dt:dt*(L-1)],Tampoints,'r.',tspan,Txsimpoints,'b',tspan,Tamsimpoints,'r'); hold on
%drawnow

figure(5)         % Figure S6 in paper
     subplot(4,5,pos(i))
     plot(Tampoints*100,Txpoints*75,'-','Color',C(j,:),'Linewidth',3); hold on
     plot(Tampoints(end)*100,Txpoints(end)*75,'o','Color',C(j,:),'Linewidth',3);hold on
     plot(Tamsimpoints*100,Txsimpoints*75,'-','Color',C(j+2,:),'Linewidth',3); hold on 
     plot(Tamsimpoints(end)*100,Txsimpoints(end)*75,'o','Color',C(j+2,:),'Linewidth',3);hold on
     axis([0 100 0 75])
     set(gca,'XTick',[0 100]); set(gca,'YTick',[0 75]);
     text(43,37,stable(i,:),'Fontsize',14,'Color',C(stc(i),:),'Linewidth',1)
drawnow

end
end

figure(5)
     subplot(4,5,16),        xlabel('125nM','Fontsize',16);
     subplot(4,5,17),        xlabel('250nM','Fontsize',16);
     subplot(4,5,18),        xlabel('500nM','Fontsize',16);
     subplot(4,5,19),        xlabel('750nM','Fontsize',16);
     subplot(4,5,20),        xlabel('1000nM','Fontsize',16);
     subplot(4,5,16),        ylabel('250nM','Fontsize',16);
     subplot(4,5,11),        ylabel('500nM','Fontsize',16);
     subplot(4,5,6) ,        ylabel('750nM','Fontsize',16);
     subplot(4,5,1) ,        ylabel('1000nM','Fontsize',16);
     subplot(4,5,18),        text(-10,-50,'[A_2^{tot}]','Fontsize',20);
     subplot(4,5,6) ,        text(-70,-70,'[A_1^{tot}]','Fontsize',20,'Rotation',90);
%    print -depsc2 Phasediagram.eps;

figure(6)           % Figure 5A (left) in paper
     x=[0:1/60:1/60*420]; y=[1:2:30 34 40:10:420]; z=[1:10:70 70:5:150 150:10:420];
     plot(x,data{43,1}*75,'r',x,data{43,2}*100,'g','Linewidth',2); hold on;
     plot(z/60,data{44,1}(z)*75,'ro',y/60,data{44,2}(y)*100-0.5,'go','Linewidth',2); 
     axis([0 7 -10 110])
     xlabel('Time (hr)','Fontsize',25); ylabel('[Sw ON] (nM)','Fontsize',25);
     legend('Sw_{21}', 'Sw_{12}'); legend boxoff; 
     set(gca,'Fontsize',25);
%    print -depsc2 PhasediagramTime1.eps;

figure(7)           % Figure 5A (right) in paper
     plot(0:1/60:1/60*414,data{49,1}*75,'r',0:1/60:1/60*414,data{49,2}*100-1,'g','Linewidth',2); hold on;
     plot(0:10/60:1/60*403,data{50,1}(1:10:404)*75+0.5,'ro',0:10/60:1/60*403,data{50,2}(1:10:404)*100-1,'go','Linewidth',2);
     axis([0 7 -10 110])
     xlabel('Time (hr)','Fontsize',25); ylabel('[Sw ON] (nM)','Fontsize',25);
     legend('Sw_{21}', 'Sw_{12}'); legend boxoff; 
     set(gca,'Fontsize',25);
%    print -depsc2 PhasediagramTime2.eps;

