function plotDNAinput_Feedforward(lparam)

% generate figures for single switches regulated by DNA inputs or feedforward circuits 

load DNAinput_Feedforward_fluorescencedata

close all

% input experimental data for single switch experiments

p=[0 20 40 60 70 80 90 100 110 130 150]/100;
D12_Dinh2_1=[96 95 95 95 92 77 31 11 2 1 2];
D21_Dinh1_05=[95 95 95 95 93 93 56 21 3 2 2]/100*75;
D21_Dinh1_1=[98 97 97 96 94 93 89 11 2 2 2]/100*75;
D21_Dinh1_15=[96 96 96 95 96 94 91 20 2 1 1]/100*75;

% input experimental data for feedforward circuits

s=[0 10 20 30 40 50 60 70 80 90 100];
D12_So2_1=[96 94 87 72 62 4 2 0 1 0 0];
D21_So1_05=[95 71 26 5 3 2 2 1 0 0 0]/100*75;
D21_So1_1=[97 93 84 54 18 2 1 0 1 0 0]/100*75;
D21_So1_15=[97 96 93 77 43 15 3 2 0 0 0]/100*75;

% input experimental gel data for a feedforward circuit

I1=[0.08 0.22 0.47 0.84 1.06 1.21 1.05 1.84 2.03 2.08 2.67];
I2=[1.62 1.58 1.78 1.69 1.08 0.84 0.45 0.74 0.79 0.65 0.71];
AI2=[100 100 96 93 82 85 66 69 75 69 70]/100;
AI1=[12 37 57 88 95 100 100 95 94 88 87]/100;
Sw1OFF=[1 1 7 61 78 91 100 99 78 90 91]/100*75;

% parameters for simulation

param=exp(lparam);

KM1=param(1); kpc1=param(2); KMF1=param(3); kpFc1=param(4); KMh1=param(5); khc1=param(6); kDA1=param(7); kAI1=param(8); kDAI1=param(9);
KM2=param(10); kpc2=param(11); KMF2=param(12); kpFc2=param(13); KMh2=param(14); khc2=param(15); kDA2=param(16); kAI2=param(17); kDAI2=param(18);
Rv=param(19); Rhv=param(20); Dv=param(21);

% enzyme concentrations

R=30*10^(-9); Rh=4.4*10^(-9);
Rt=R*Rv; Rht=Rh*Rhv;

L=40;
dt=60;

% generate simulation data

DSw=[1 0 0 0];
Act=[1 0.5 1 1.5]*10^(-6);

DNAsimpoints=zeros(4,L);  % single switches regulated by DNA inputs

for j=1:4,

	Actin=Act(j);
        Actout=1*10^(-6);

for i=1:L,
	Inhfrac=(i-1)*1.5/L;

tspan=[0:dt:180*60];
options=odeset('AbsTol',1e-10); % Set tolerances

if DSw(j),    % DSw=1: DInh2 -| Sw12 ,  DSw=0: DInh1 -| Sw21

% x0=[D1 A1 DI1 D1A1 A1DI1 A2 I2 A2I2];

x0=[0 Actin-140*10^(-9) Inhfrac*Actin 100*10^(-9) 0 Actout 0 0]'; 

[t,y]=ode23s('DNAinputdefine',tspan,x0, options,  KM2, kpc2, KMF2, kpFc2, KMh2, khc2, kDA2, kAI2, kDAI2, KM1, kpc1, KMF1, kpFc1, KMh1, khc1, kDA1, kAI1, kDAI1, Rt, Rht);

DNAsimpoints(j,i)=y(180,4)/10^(-9);

else 

x0=[0 Actin-75*10^(-9) Inhfrac*Actin 75*10^(-9) 0 Actout 0 0]'; 

[t,y]=ode23s('DNAinputdefine',tspan,x0, options,  KM1, kpc1, KMF1, kpFc1, KMh1, khc1, kDA1, kAI1, kDAI1, KM2, kpc2, KMF2, kpFc2, KMh2, khc2, kDA2, kAI2, kDAI2, Rt, Rht);

DNAsimpoints(j,i)=y(180,4)/10^(-9);

end
end
end


Sw=[1 0 2 0];

DAsimpoints=zeros(4,L);    % Feedforward circuits
A1I1simpoints=zeros(1,L);
A2I2simpoints=zeros(1,L);
I1totsimpoints=zeros(1,L);
I2totsimpoints=zeros(1,L);

for j=1:4, 

    Actin=Act(j);
    Actout=1*10^(-6);

for i=1:L,

ONfrac=(i-1)*1/(L-1);


tspan=[0:dt:180*60];
options=odeset('AbsTol',1e-10); % Set tolerances

if Sw(j)==1,    % Sw=1: So2 -| Sw12 ,  Sw=0: So1 -| Sw21

% x0=[D1 A1 I1 D1A1 A1I1 D2 A2 I2 D2A2 A2I2];

x0=[75*10^(-9)*(1-ONfrac) Actin 0 75*10^(-9)*ONfrac 0 0 Actout-100*10^(-9) 0 100*10^(-9) 0]'; 

[t,y]=ode23s('Feedforwarddefine',tspan,x0, options,  KM1, kpc1, KMF1, kpFc1, KMh1, khc1, kDA1, kAI1, kDAI1, KM2, kpc2, KMF2, kpFc2, KMh2, khc2, kDA2, kAI2, kDAI2, Rt, Rht);

DAsimpoints(j,i)=y(180,9)/10^(-9);

else if Sw(j)==2,  % Sw=2: So1 -| Sw21,  gel data available
x0=[100*10^(-9)*(1-ONfrac) Actout 0  100*10^(-9)*ONfrac 0 0 Actin-75*10^(-9) 0 75*10^(-9) 0]'; 

[t,y]=ode23s('Feedforwarddefine',tspan,x0, options,  KM2, kpc2, KMF2, kpFc2, KMh2, khc2, kDA2, kAI2, kDAI2, KM1, kpc1, KMF1, kpFc1, KMh1, khc1, kDA1, kAI1, kDAI1, Rt, Rht);
DAsimpoints(j,i)=y(180,9)/10^(-9);
A1I1simpoints(i)=y(180,10)/10^(-6);
A2I2simpoints(i)=y(180,5)/10^(-6);
I1totsimpoints(i)=(y(180,8)+y(180,10))/10^(-6);
I2totsimpoints(i)=(y(180,3)+y(180,5))/10^(-6);

else 
x0=[100*10^(-9)*(1-ONfrac) Actout 0  100*10^(-9)*ONfrac 0 0 Actin-75*10^(-9) 0 75*10^(-9) 0]'; %'

[t,y]=ode23s('Feedforwarddefine',tspan,x0, options,  KM2, kpc2, KMF2, kpFc2, KMh2, khc2, kDA2, kAI2, kDAI2, KM1, kpc1, KMF1, kpFc1, KMh1, khc1, kDA1, kAI1, kDAI1, Rt, Rht);
DAsimpoints(j,i)=y(180,9)/10^(-9);

end
end
end
end

% plot Figures

x=linspace(0,100,L);

figure(1)          % Figure 2C in paper
     plot(x*1.5/100,DNAsimpoints(1,:),'b-',p*1,D12_Dinh2_1,'bo','Linewidth',2)
     xlabel('[dI_2^{tot}] (\muM)','Fontsize',25);
     ylabel('[Sw_{12} ON] (nM)','Fontsize',25);
     legend('[A_2^{tot}]=1 \muM');
     legend boxoff;
     axis([0 1.5 -10 110]);  
     set(gca,'Fontsize',25);
   % print -depsc2 Dinh2.eps;

figure(2)          % Figure 2B in paper
     plot(x*0.75/100,DNAsimpoints(2,:),'r-',x*1.5/100,DNAsimpoints(3,:),'b-',x*2.25/100,DNAsimpoints(4,:),'g-',p*0.5,D21_Dinh1_05,'ro',p*1,D21_Dinh1_1,'bo',p*1.5,D21_Dinh1_15,'go','Linewidth',2)
     xlabel('[dI_1^{tot}] (\muM)','Fontsize',25);
     ylabel('[Sw_{21} ON] (nM)','Fontsize',25);
     legend('[A_1^{tot}]=0.5 \muM','[A_1^{tot}]=1 \muM','[A_1^{tot}]=1.5 \muM');
     legend boxoff;
     set(gca,'YTick',[0 15 30 45 60 75]);
     axis([0 3 -7 82]);    
     set(gca,'Fontsize',25);
   % print -depsc2 Dinh1.eps;

figure(3)           % Figure 2F in paper
     plot(x*75/100,DAsimpoints(1,:),'b-',s*75/100,D12_So2_1,'bo','Linewidth',2)
     xlabel('[So_2 ON] (nM)','Fontsize',25);
     ylabel('[Sw_{12} ON] (nM)','Fontsize',25);
     legend('[A_2^{tot}]=1 \muM');
     legend boxoff;
     set(gca,'XTick',[0 15 30 45 60 75]);
     axis([0 75 -10 110]);
     set(gca,'Fontsize',25);
   % print -depsc2 Soinh2.eps;

figure(4)           % Figure 2E in paper
     plot(x,DAsimpoints(2,:),'r-',x,DAsimpoints(3,:),'b-',x,DAsimpoints(4,:),'g-',s,D21_So1_05,'ro',s,D21_So1_1,'bo',s,D21_So1_15,'go','Linewidth',2)
     xlabel('[So_1 ON] (nM)','Fontsize',25);
     ylabel('[Sw_{21} ON] (nM)','Fontsize',25);
     legend('[A_1^{tot}]=0.5 \muM','[A_1^{tot}]=1 \muM','[A_1^{tot}]=1.5 \muM');
     legend boxoff;
     set(gca,'YTick',[0 15 30 45 60 75]);
     axis([0 100 -7 82])
     set(gca,'Fontsize',25);
  %  print -depsc2 Soinh1.eps;

figure(5)           % Figure 3B in paper
     plot(x,I1totsimpoints+0.02,'r',x,I2totsimpoints+0.02,'b','Linewidth',3);
     hold on
	 plot(x,A1I1simpoints,'c',x,A2I2simpoints,'m','Linewidth',2);
     plot(s,I1,'ro',s,I2,'bo',s,AI1,'co',s,AI2,'mo','Linewidth',2);
     xlabel('[So_1 ON] (nM)','Fontsize',25);
     ylabel('Concentration (\muM)','Fontsize',25);
     legend('Inh_1tot','Inh_2tot','Act_1Inh_1','Act_2Inh_2','Location','SouthEastOutside');
     set(gca,'Fontsize',25);
     axis([0 100 -0.3 3]);
     text(102,0,'0','Fontsize',25,'Color',[0 0 0]);
     text(102,1,'25','Fontsize',25,'Color',[0 0 0]);
     text(102,2,'50','Fontsize',25,'Color',[0 0 0]);
     text(102,3,'75','Fontsize',25,'Color',[0 0 0]);
     text(110,0.7,'[T_{21}] (nM)','Fontsize',25,'Rotation',90,'Color',[0 0 0]);
%    print -depsc2 DgelRNA.eps;

figure(6)           % Figure 3A in paper
     plot(s,75-Sw1OFF,'ro','Linewidth',2); hold on
     plot(s,D21_So1_1,'bo','Linewidth',2); 
     plot(x,DAsimpoints(3,:),'k-','Linewidth',2);
     legend('Gel data','Fluorometer data','Model');
     set(gca,'Fontsize',25);
     legend boxoff;
     set(gca,'YTick',[0 15 30 45 60 75]);
     axis([0 100 -7 82]);
     xlabel('[So_1 ON] (nM)','Fontsize',25);
     ylabel('[Sw_{21} ON] (nM)','Fontsize',25);
%    print -depsc2 DgelT.eps; 

figure(7)           % Figure 2B in paper
     x=0:1/60:242/60;
     plot(x,[So2_0n(1:243); So2_10n(1:243); So2_20n(1:243); So2_30n(1:243); So2_40n(1:243); So2_50n(1:243); So2_60n(1:243); So2_70n(1:243); So2_80n(1:243); So2_90n(1:243); So2_100n(1:243)] ,'Linewidth',2)
     set(gca,'Fontsize',25)
     ylabel('Normalized fluorescence','Fontsize',25)
     xlabel('Time (hr)','Fontsize',25)
     axis([-1/60 250/60 -0.1 1.1])
%    print -depsc2 FFfluo.eps 

figure(8)           % Figure 2A in paper
     x=0:1/60:259/60;
     plot(x,[D1_0n; D1_20n; D1_40n; D1_60n; D1_70n; D1_80n; D1_90n; D1_100n; D1_110n; D1_130n; D1_150n],'-','Linewidth',2)
     set(gca,'Fontsize',25)
     ylabel('Normalized fluorescence','Fontsize',25)
     xlabel('Time (hr)','Fontsize',25)
     axis([-1/60 260/60 -0.1 1.1])
%    print -depsc2 dIfluo.eps 

figure(9)            % Figure 4 in paper
     plot(D12_So2_1,s*75/100,'gs--',s,D21_So1_1,'rs--','Linewidth',2);
     set(gca,'Fontsize',20)
     ylabel('[Sw_{21} ON] (nM)','Fontsize',20)
     xlabel('[Sw_{12} ON] (nM)','Fontsize',20)
     set(gca,'YTick',[0 15 30 45 60 75]);
     axis([-10 110 -7 82])
%    print -depsc2 Phaseportrait.eps 

figure(10)            % Figure S3A in paper
     plot(p/0.92,D21_Dinh1_05,'ro-',p/0.951,D21_Dinh1_1,'bo-',p/0.958,D21_Dinh1_15,'go-','Linewidth',2); 
     legend('[A_1^{tot}]=0.5 \muM','[A_1^{tot}]=1 \muM','[A_1^{tot}]=1.5 \muM');
     legend boxoff;
     set(gca,'Fontsize',20)
     xlabel('[dI_1^{tot}]/K','Fontsize',20)
     ylabel('[Sw_{21} ON] (nM)','Fontsize',20)
     set(gca,'YTick',[0 15 30 45 60 75]);
     axis([0 2 -7 82])
%    print -depsc2 dI1scaled.eps 

figure(11)            % Figure S3B in paper
     plot(s/14.82,D21_So1_05,'ro-',s/31.3,D21_So1_1,'bo-',s/38.15,D21_So1_15,'go-','Linewidth',2); 
     legend('[A_1^{tot}]=0.5 \muM','[A_1^{tot}]=1 \muM','[A_1^{tot}]=1.5 \muM');
     legend boxoff;
     set(gca,'Fontsize',20)
     xlabel('[So_1 ON]/K','Fontsize',20)
     ylabel('[Sw_{21} ON] (nM)','Fontsize',20)
     set(gca,'YTick',[0 15 30 45 60 75]);
     axis([0 2 -7 82])
%    print -depsc2 So1scaled.eps 



